#!/bin/sh
#
# seqsee install script
#

PACKAGE="seqsee"
echo ""
echo " ************************************************"
echo " Welcome to the seqsee installation script"
echo " ************************************************"
echo ""
echo ""

####################################################################
#
# check version of seqsee 
#
SEQSEE_VERSION=`cat ../Lib/seqsee/VERSION | awk 'NF == 1 {print $0}'`
if test "x" = "x${SEQSEE_VERSION}"; then
	echo ""
	echo " *** Error *** "
	echo "I could not determine the version of seqsee."
	echo "Are you in the download directory and did you type './install.sh'?"
	echo ""
	exit 1
fi

OS_MAC_INTEL=darwin-univ-aqua
OS_MAC_PPC=darwin-ppc-aqua
OS_LINUX_32=linux-x86
OS_LINUX_64=linux-x86_64


os_type=unknown
osbool=`uname -a | grep -i "Darwin"`
if test x != "x${osbool}"; then
    arch=`uname -a | grep -i "Power"`
    if test x != "x${arch}"; then
        os_type=$OS_MAC_PPC
    else
        os_type=$OS_MAC_INTEL
    fi
else
    osbool=`uname -a | grep -i "Linux"`
    if test x != "x${osbool}"; then
        arch=`uname -a | grep -i "x86_64"`
        if test x != "x${arch}"; then
            os_type=$OS_LINUX_64
        else
            os_type=$OS_LINUX_32
        fi
    fi
fi
if test ! -d ../Bin/$os_type; then
	echo ""
	echo " I do not have executables for '$os_type'."
	echo " Perhaps this is a software packaging error."
	echo ""
	exit 1
fi

echo " Binary Type: $os_type"
if test $os_type = "unknown"; then
	echo ""
	echo " I do not recognize your operating system '$os_type'."
	echo " Here is what I support:"
	echo ""
	echo "   linux   ('uname -s' = Linux)"
	echo "   mac OSX ('uname -s' = Darwin)"
	echo ""
	exit 1
fi

####################################################################
#
# Now let's decide where you want to put seqsee
#
SEQSEE_DEFAULT_DIR=$HOME/seqsee-$SEQSEE_VERSION
echo ""
echo " Enter the full pathname for the installation of seqsee."
echo ""
echo " Examples: /usr/local/packages/seqsee"
echo "           /usr/local/bdslab/seqsee"
echo "           $SEQSEE_DEFAULT_DIR"
echo ""
while read response
do
    if test x = "x${response}"; then
		echo " Please enter a full pathname response."
		continue
	fi
	if test -e $response; then
		echo ""
		echo " The directory '$response' already exists."
		echo " Seqsee should be installed in a new directory."
		echo ""
		exit 1
	else
		break
	fi
done


####################################################################
#
# last chance before we start
#
SEQSEE_DIR=$response
echo ""
echo ""
echo ""
echo " ****************************************************"
echo " #"
echo " # Here is where I am installing seqsee"
echo " #"
echo " # seqsee.......: $SEQSEE_DIR"
echo " #"
echo " ****************************************************"
echo ""
echo ""
echo " Start the installation (y/n)?"
echo ""
while read response
do
	if test "xy" = "x${response}"; then
		break
	fi	
	if test "xn" = "x${response}"; then
		echo ""
		echo " Terminating seqsee Install..."
		echo ""
		exit 1	
	fi	
	echo " Continue with the installation (y/n)?"
	echo ""
done

####################################################################
# 
# create seqsee directory according to user choices
#
echo " "
echo " ****************************************************"
echo " "
echo " Executing installation script..."
echo " "
TMP_DIR="/tmp/seqsee-${SEQSEE_VERSION}"
BIN_DIR=$TMP_DIR/bin
LIB_DIR=$TMP_DIR/lib

\rm -rf $TMP_DIR
mkdir $TMP_DIR 

cp -r ../Lib $LIB_DIR
echo " Copying Binaries for $os_type"
cp -r ../Bin/$os_type $BIN_DIR

#
# create shell script with environment variable set for selected executables
#
echo " Editing startup shell script for $PACKAGE..."
cp $BIN_DIR/$PACKAGE $BIN_DIR/${PACKAGE}_
cp seqstart $BIN_DIR/$PACKAGE
echo "setenv SEQSEE_BIN ${SEQSEE_DIR}/bin" >> $BIN_DIR/$PACKAGE
echo "setenv SEQSEE_LIB ${SEQSEE_DIR}/lib/seqsee" >> $BIN_DIR/$PACKAGE
echo "${SEQSEE_DIR}/bin/seqsee_ \$*" >> $BIN_DIR/$PACKAGE
echo "unsetenv SEQSEE_BIN" >> $BIN_DIR/$PACKAGE
echo "unsetenv SEQSEE_LIB" >> $BIN_DIR/$PACKAGE
chmod +x $BIN_DIR/$PACKAGE

#
# set up SEQSEE parameter file "seqsee.parms"
#
echo " Updating parameter file '$SEQSEE_DIR/lib/seqsee/seqsee.parms'..."
./xparms.sh $SEQSEE_DIR/lib/seqsee $SEQSEE_DIR/bin > $LIB_DIR/seqsee/seqsee.parms

# just make sure we have read permission on everything
chmod -R go+r $TMP_DIR

# move it, user confirmed it was ok to do this.
rm -rf $SEQSEE_DIR
mv $TMP_DIR $SEQSEE_DIR

############################################################

if test -x $SEQSEE_DIR/bin/seqsee; then
	echo " "
	echo " Installation is now complete. "
	echo " Please make sure seqsee works as advertised."
	echo " See the Examples section of the documentation."
	echo " "
	echo "     www.bionmr.ualberta.ca/bds/software/seqsee/latest"
	echo " "
	echo " The seqsee startup script can be found at:"
	echo " "
	echo "     $SEQSEE_DIR/bin/seqsee"
	echo " "
	echo " "
	exit 0
fi

echo " "
echo " The seqsee startup script did not get created."
echo " Please investigate messages reported by this installation script."
echo " Please report errors to the author."
echo " "
